@@ -55,18 +55,17 @@ class Demo(Module):
     self._display_password()
 
   @Module.laboro_method
-  def show_argument(self, argument, crumb):
-    """Log the specified ``argument`` and the ``crumb`` value.
+  def show_argument(self, argument):
+    """Log the specified ``argument``.
 
     Arguments:
       ``argument``: A string value specifying one of the argument given to ``__init__``.
-      ``crumb``: Any value to be logged as its string representation.
 
     Raises:
       ``laboro.error.LaboroError``: Whenever the ``argument`` value is not a valid argument name.
     """
     arg_value = self.get_arg_value_as_string(argument)
-    logging.info(f"This is a demo: {argument}: {arg_value} / crumb: {crumb}")
+    logging.info(f"This arg was given at init time: {argument}: {arg_value}")
 
   @Module.laboro_method
   def get_value_from_dict(self, key):
@@ -77,3 +76,16 @@ class Demo(Module):
   def show_list(self, arg_list):
     for item in arg_list:
       logging.info(f"- {item}")
+
+  @Module.laboro_method
+  def show_dict(self, arg_dict):
+    for key, value in arg_dict.items():
+      logging.info(f"- {key}: {value}")
+
+  @Module.laboro_method
+  def show_dict_value(self, arg_dict, key):
+    logging.info(f"{key}: {arg_dict[key]}")
+
+  @Module.laboro_method
+  def show_value(self, value):
+    logging.info(f"This is the given value: {value}")
